@@ -27,7 +27,7 @@ import urllib
 from dataclasses import dataclass
 from functools import partial
 from typing import Dict, Mapping, Optional, Tuple, Union
-
+import tqdm
 from datalabs.features import Features
 from datalabs.utils.mock_download_manager import MockDownloadManager
 
@@ -54,6 +54,7 @@ from .utils.file_utils import DownloadConfig, is_remote_url
 from .utils.filelock import FileLock
 from .utils.info_utils import get_size_checksum_dict, verify_checksums, verify_splits
 from .utils.streaming_download_manager import StreamingDownloadManager
+from multiprocess import Pool
 
 import sys
 
@@ -218,6 +219,7 @@ class DatasetBuilder:
         data_dir: Optional[str] = None,
         dataset_class = Dataset,
         feature_expanding:bool = False,
+        num_proc: int = 1,
         **config_kwargs,
     ):
         """Constructs a DatasetBuilder.
@@ -254,6 +256,7 @@ class DatasetBuilder:
         self.namespace = namespace
         self.dataset_class = dataset_class
         self.feature_expanding = feature_expanding
+        self.num_proc = num_proc
 
         if data_files is not None and not isinstance(data_files, DataFilesDict):
             data_files = DataFilesDict.from_local_or_remote(
@@ -1078,6 +1081,10 @@ class GeneratorBasedBuilder(DatasetBuilder):
         """
         raise NotImplementedError()
 
+    @abc.abstractmethod
+    def _sample_feature_expanding(self, sample):
+        raise NotImplementedError()
+
     def _prepare_split(self, split_generator):
         split_info = split_generator.split_info
 
@@ -1094,15 +1101,25 @@ class GeneratorBasedBuilder(DatasetBuilder):
             check_duplicates=True,
         ) as writer:
             try:
-                for key, record in utils.tqdm(
+                if self.feature_expanding:
+                    if self.num_proc == 1:
+                        generator = map(lambda i: i[1], generator)
+                    else:
+                        with Pool(processes=self.num_proc) as pool:
+                            generator = pool.map(lambda i: i[1], generator)
+                    generator = enumerate(generator)
+
+                iter = utils.tqdm(
                     generator,
                     unit=" examples",
                     total=split_info.num_examples,
                     leave=False,
                     disable=bool(logging.get_verbosity() == logging.NOTSET),
-                ):
+                )
+                for key, record in iter:
                     example = self.info.features.encode_example(record)
                     writer.write(example, key)
+
             finally:
                 num_examples, num_bytes = writer.finalize()
 
